<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Theme Customizer</source>
        <translation>Theme Customizer</translation>
    </message>
    <message>
        <source>Export theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select .tgz file to import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Restore theme files</source>
        <translation>Restaurar archivos del tema</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Delete saved themes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Selected theme is currently in use!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>You can&apos;t delete a theme that&apos;s currently active.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Delete theme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Are you sure you want to delete this theme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Theme deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>You must give name for the theme.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Folder </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source> already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Saving new theme...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Save as new theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Menu bar opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Creating backups...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>You must give name for the preset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Preset saved!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Preset loaded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Preset deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up font family...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up font sizes...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up font colors...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up icon theme...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up snap-to-grid...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up shortcut and bookmark sizes...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up widget opacities...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restarting services...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restoring files, please wait...</source>
        <translation>Restaurando archivos, por favor espere...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Theme Customizer - restore files</source>
        <translation>Theme Customizer - Restaurar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Do you want to restore all original theme files?</source>
        <translation>Desea restaurar los archivos originales del tema?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restoring files from backup</source>
        <translation>Restaurando archivos desde backup</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings...</source>
        <translation>Leyendo cofiguración...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings</source>
        <translation>Leyendo configuración</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Ok, thanks.</source>
        <translation>Ok, gracias.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Overwrite color preset?</source>
        <translation>Sobreescribir color predefinido?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color preset with this name already exists, do you want to overwrite it?</source>
        <translation>Ya existe un color predefinido con ese nombre, desea sobreescribirlo?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Delete color preset?</source>
        <translation>Borrar color predefinido?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Are you sure you want to delete this preset?</source>
        <translation>Esta seguro que desea borrar esta predefinición?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color presets</source>
        <translation>Colores predefinidos</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Save color preset</source>
        <translation>Guardar color predefinido</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>Font size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>DEFAULT</source>
        <translation>Por Defecto</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>-5</source>
        <translation>-5</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>-3</source>
        <translation>-3</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>-1</source>
        <translation>-1</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <source>+1</source>
        <translation>+1</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>+3</source>
        <translation>+3</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <source>+5</source>
        <translation>+5</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>Font colors</source>
        <translation>Colores</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Primary font</source>
        <translation>Primaria</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="242"/>
        <source>Secondary font</source>
        <translation>Secundaria</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>Active font</source>
        <translation>Activo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Disabled font</source>
        <translation>Deshabilitada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="360"/>
        <source>Painted font</source>
        <translation>Coloreada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button font</source>
        <translation>Botón</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button pressed</source>
        <translation>Botón presionado</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>&quot;Paint&quot; color</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Icon theme</source>
        <translation>Iconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Homescreen</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Show app shortcut backgrounds</source>
        <translation>Fondo de íconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Snap-to-grid size</source>
        <translation>Ajuste a cuadrícula</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Widget opacity</source>
        <translation>Opacidad de fondo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>App shortcut size</source>
        <translation>Tamaño de íconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <source>Web bookmark size</source>
        <translation>Tamaño de favoritos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="721"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <source>Auto-reboot after saving settings</source>
        <translation>Auto-reiniciar después de guardar cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="751"/>
        <location filename="mainwindow.cpp" line="352"/>
        <source>Apply changes</source>
        <translation>Aplicar cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Test</source>
        <translation>Testeo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>Import fonts from folder</source>
        <translation>Imporar fuentes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="783"/>
        <source>Import all font files from MyDocs</source>
        <translation>Instalar todas las fuentes desde MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Change backgrounds</source>
        <translation>Cambiar fondo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <source>Setting up the theme, please wait...</source>
        <translation>Configurando el tema, por favor espere...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Searching and importing fonts, please wait...</source>
        <translation>Buscando e importando fuentes, por favor espere...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>Save and reboot</source>
        <translation>Guardar y reiniciar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - Importar fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>Desea importar las fuentes desde MyDocs?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>Nota: esta función sólo importará fuentes .ttf y .otf desde la raíz de MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="370"/>
        <source>Importing fonts</source>
        <translation>Importando fuentes</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>About Theme Customizer</source>
        <translation>Acerca de Theme Customizer</translation>
    </message>
</context>
<context>
    <name>backgrounds</name>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Clock</source>
        <translation>Reloj</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>App Manager</source>
        <translation>Admin Aplicaciones</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Media Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Lockscreen</source>
        <translation>Pant Bloqueo</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Tap me to change</source>
        <translation>Tocar para cambiar</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Set image</source>
        <translation>Definir imagen</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Backgrounds</source>
        <translation>Fondos</translation>
    </message>
    <message>
        <location filename="backgrounds.cpp" line="0"/>
        <source>Select image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.cpp" line="0"/>
        <source>Processing image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.cpp" line="0"/>
        <source>Image saved!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>savepreset</name>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset as...</source>
        <translation>Guardar color predefinido como...</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset</source>
        <translation>Guardar color predefinido</translation>
    </message>
</context>
<context>
    <name>managepresets</name>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Choose color preset:</source>
        <translation>Seleccionar color predefinido:</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Currently active colors</source>
        <translation>Colores activos</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Manage color presets</source>
        <translation>Administrar colores</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Original colors of current theme</source>
        <translation>Colores originales del tema actual</translation>
    </message>
</context>
<context>
    <name>savenewtheme</name>
    <message>
        <location filename="savenewtheme.ui" line="0"/>
        <source>Save theme as...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="savenewtheme.ui" line="0"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>managethemes</name>
    <message>
        <location filename="managethemes.ui" line="0"/>
        <source>Select theme:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="managethemes.ui" line="0"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="managethemes.cpp" line="0"/>
        <source>No themes created by Theme Customizer found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
